"""
Colex
=====

Library with constants and functions for working with colors

Includes
--------

- Annotations
  - `ColorValue`
  - `ColorCode`
  - `HexCode`
- Functions
  - `colorize`
  - `from_ansi`
  - `from_hex`
  - `from_random`
  - `from_rgb`
- Constants
  - `NONE`
  - `RESET`
- Modules with constants
  - `color`
    - HTML/CSS named colors
  - `style`
    - `BOLD`
    - `FAINT`
    - `ITALIC`
    - `UNDERLINE`
    - `BLINK`
    - `RAPID_BLINK`
    - `REVERSE`
    - `CONCEAL`
    - `STRIKETHROUGH`
"""

__all__ = (
    # Annotations
    "ColorValue",
    "ColorCode",
    "HexCode",
    # Functions
    "colorize",
    "from_ansi",
    "from_hex",
    "from_random",
    "from_rgb",
    # Special constants
    "NONE",
    "RESET",
    # Style constants
    "style",  # Module
    "BOLD",
    "FAINT",
    "ITALIC",
    "UNDERLINE",
    "BLINK",
    "RAPID_BLINK",
    "REVERSE",
    "CONCEAL",
    "STRIKETHROUGH",
    # Color constants
    "color",  # Module
    "ALICE_BLUE",
    "ANTIQUE_WHITE",
    "AQUA",
    "AQUAMARINE",
    "AZURE",
    "BEIGE",
    "BISQUE",
    "BLACK",
    "BLANCHED_ALMOND",
    "BLUE",
    "BLUE_VIOLET",
    "BROWN",
    "BURLY_WOOD",
    "CADET_BLUE",
    "CHARTREUSE",
    "CHOCOLATE",
    "CORAL",
    "CORNFLOWER_BLUE",
    "CORNSILK",
    "CRIMSON",
    "CYAN",
    "DARK_BLUE",
    "DARK_CYAN",
    "DARK_GOLDENROD",
    "DARK_GRAY",
    "DARK_GREEN",
    "DARK_KHAKI",
    "DARK_MAGENTA",
    "DARK_OLIVE_GREEN",
    "DARK_ORANGE",
    "DARK_ORCHID",
    "DARK_RED",
    "DARK_SALMON",
    "DARK_SEA_GREEN",
    "DARK_SLATE_BLUE",
    "DARK_SLATE_GRAY",
    "DARK_TURQUOISE",
    "DARK_VIOLET",
    "DEEP_PINK",
    "DEEP_SKY_BLUE",
    "DIM_GRAY",
    "DODGER_BLUE",
    "FIREBRICK",
    "FLORAL_WHITE",
    "FOREST_GREEN",
    "FUCHSIA",
    "GAINSBORO",
    "GHOST_WHITE",
    "GOLD",
    "GOLDENROD",
    "GRAY",
    "GREEN",
    "GREEN_YELLOW",
    "HONEYDEW",
    "HOT_PINK",
    "INDIAN_RED",
    "INDIGO",
    "IVORY",
    "KHAKI",
    "LAVENDER",
    "LAVENDER_BLUSH",
    "LAWN_GREEN",
    "LEMON_CHIFFON",
    "LIGHT_BLUE",
    "LIGHT_CORAL",
    "LIGHT_CYAN",
    "LIGHT_GOLDENROD_YELLOW",
    "LIGHT_GRAY",
    "LIGHT_GREEN",
    "LIGHT_PINK",
    "LIGHT_SALMON",
    "LIGHT_SEA_GREEN",
    "LIGHT_SKY_BLUE",
    "LIGHT_SLATE_GRAY",
    "LIGHT_STEEL_BLUE",
    "LIGHT_YELLOW",
    "LIME",
    "LIME_GREEN",
    "LINEN",
    "MAGENTA",
    "MAROON",
    "MEDIUM_AQUAMARINE",
    "MEDIUM_BLUE",
    "MEDIUM_ORCHID",
    "MEDIUM_PURPLE",
    "MEDIUM_SEA_GREEN",
    "MEDIUM_SLATE_BLUE",
    "MEDIUM_SPRING_GREEN",
    "MEDIUM_TURQUOISE",
    "MEDIUM_VIOLET_RED",
    "MIDNIGHT_BLUE",
    "MINT_CREAM",
    "MISTY_ROSE",
    "MOCCASIN",
    "NAVAJO_WHITE",
    "NAVY",
    "OLD_LACE",
    "OLIVE",
    "OLIVE_DRAB",
    "ORANGE",
    "ORANGE_RED",
    "ORCHID",
    "PALE_GOLDENROD",
    "PALE_GREEN",
    "PALE_TURQUOISE",
    "PALE_VIOLET_RED",
    "PAPAYA_WHIP",
    "PEACH_PUFF",
    "PERU",
    "PINK",
    "PLUM",
    "POWDER_BLUE",
    "PURPLE",
    "RED",
    "ROSY_BROWN",
    "ROYAL_BLUE",
    "SADDLE_BROWN",
    "SALMON",
    "SANDY_BROWN",
    "SEA_GREEN",
    "SEA_SHELL",
    "SIENNA",
    "SILVER",
    "SKY_BLUE",
    "SLATE_BLUE",
    "SLATE_GRAY",
    "SNOW",
    "SPRING_GREEN",
    "STEEL_BLUE",
    "TAN",
    "TEAL",
    "THISTLE",
    "TOMATO",
    "TURQUOISE",
    "VIOLET",
    "WHEAT",
    "WHITE",
    "WHITE_SMOKE",
    "YELLOW",
    "YELLOW_GREEN",
)

from ._annotations import (
    ColorValue,
    ColorCode,
    HexCode,
)
from ._functions import (
    colorize,
    from_ansi,
    from_hex,
    from_random,
    from_rgb,
)
from ._special import (
    NONE,
    RESET,
)
import style
from style import (
    BLINK,
    BOLD,
    CONCEAL,
    FAINT,
    ITALIC,
    RAPID_BLINK,
    REVERSE,
    STRIKETHROUGH,
    UNDERLINE,
)
import color
from .color import (
    ALICE_BLUE,
    ANTIQUE_WHITE,
    AQUA,
    AQUAMARINE,
    AZURE,
    BEIGE,
    BISQUE,
    BLACK,
    BLANCHED_ALMOND,
    BLUE,
    BLUE_VIOLET,
    BROWN,
    BURLY_WOOD,
    CADET_BLUE,
    CHARTREUSE,
    CHOCOLATE,
    CORAL,
    CORNFLOWER_BLUE,
    CORNSILK,
    CRIMSON,
    CYAN,
    DARK_BLUE,
    DARK_CYAN,
    DARK_GOLDENROD,
    DARK_GRAY,
    DARK_GREEN,
    DARK_KHAKI,
    DARK_MAGENTA,
    DARK_OLIVE_GREEN,
    DARK_ORANGE,
    DARK_ORCHID,
    DARK_RED,
    DARK_SALMON,
    DARK_SEA_GREEN,
    DARK_SLATE_BLUE,
    DARK_SLATE_GRAY,
    DARK_TURQUOISE,
    DARK_VIOLET,
    DEEP_PINK,
    DEEP_SKY_BLUE,
    DIM_GRAY,
    DODGER_BLUE,
    FIREBRICK,
    FLORAL_WHITE,
    FOREST_GREEN,
    FUCHSIA,
    GAINSBORO,
    GHOST_WHITE,
    GOLD,
    GOLDENROD,
    GRAY,
    GREEN,
    GREEN_YELLOW,
    HONEYDEW,
    HOT_PINK,
    INDIAN_RED,
    INDIGO,
    IVORY,
    KHAKI,
    LAVENDER,
    LAVENDER_BLUSH,
    LAWN_GREEN,
    LEMON_CHIFFON,
    LIGHT_BLUE,
    LIGHT_CORAL,
    LIGHT_CYAN,
    LIGHT_GOLDENROD_YELLOW,
    LIGHT_GRAY,
    LIGHT_GREEN,
    LIGHT_PINK,
    LIGHT_SALMON,
    LIGHT_SEA_GREEN,
    LIGHT_SKY_BLUE,
    LIGHT_SLATE_GRAY,
    LIGHT_STEEL_BLUE,
    LIGHT_YELLOW,
    LIME,
    LIME_GREEN,
    LINEN,
    MAGENTA,
    MAROON,
    MEDIUM_AQUAMARINE,
    MEDIUM_BLUE,
    MEDIUM_ORCHID,
    MEDIUM_PURPLE,
    MEDIUM_SEA_GREEN,
    MEDIUM_SLATE_BLUE,
    MEDIUM_SPRING_GREEN,
    MEDIUM_TURQUOISE,
    MEDIUM_VIOLET_RED,
    MIDNIGHT_BLUE,
    MINT_CREAM,
    MISTY_ROSE,
    MOCCASIN,
    NAVAJO_WHITE,
    NAVY,
    OLD_LACE,
    OLIVE,
    OLIVE_DRAB,
    ORANGE,
    ORANGE_RED,
    ORCHID,
    PALE_GOLDENROD,
    PALE_GREEN,
    PALE_TURQUOISE,
    PALE_VIOLET_RED,
    PAPAYA_WHIP,
    PEACH_PUFF,
    PERU,
    PINK,
    PLUM,
    POWDER_BLUE,
    PURPLE,
    RED,
    ROSY_BROWN,
    ROYAL_BLUE,
    SADDLE_BROWN,
    SALMON,
    SANDY_BROWN,
    SEA_GREEN,
    SEA_SHELL,
    SIENNA,
    SILVER,
    SKY_BLUE,
    SLATE_BLUE,
    SLATE_GRAY,
    SNOW,
    SPRING_GREEN,
    STEEL_BLUE,
    TAN,
    TEAL,
    THISTLE,
    TOMATO,
    TURQUOISE,
    VIOLET,
    WHEAT,
    WHITE,
    WHITE_SMOKE,
    YELLOW,
    YELLOW_GREEN,
)
